<?php
namespace WC_Delivery_Time\Includes;

use WC_Delivery_Time\Includes\Helper\Model;

class WC_Delivery_Time_Conditions
{
    public static $instance = NULL;
    private $model;

    public static function get_instance()
    {
        NULL === self::$instance and self::$instance = new self;
        return self::$instance;
    }

    public function __construct() {
        $this->model = Model::get_instance();
        add_filter('delivery_time_show_condition', [$this, 'check_category_ignore_condition'], 10, 1);
        add_filter('delivery_time_show_condition', [$this, 'shipping_method_show_condition'], 11, 1);
        add_filter('delivery_time_show_condition', [$this, 'disable_for_virtual_products'], 12, 1);

    }

    public function check_category_ignore_condition($show) {
        $cart_items = \WC()->cart->cart_contents;
        $has_none_cat_ignore = 0;
        foreach($cart_items as $item) {
            $product_id = $item['product_id'];
            $has_cat_ignore = 0;

            $product_cats = get_the_terms( $product_id, 'product_cat' );
            if(isset($product_cats) and !empty($product_cats)) {
                foreach ($product_cats as $key => $term) {
                    $term_id = $term->term_id;
                    $cat_ignore = get_term_meta($term_id, '_wcdt_cat_ignore', true);
                    if(isset($cat_ignore) and !empty($cat_ignore)) $has_cat_ignore++;

                }
            }
            if($has_cat_ignore === 0) $has_none_cat_ignore++;

        }
        if($has_none_cat_ignore > 0) return $show;
        return false;
    }

    public function shipping_method_show_condition($show) {
        $chosen_methods = WC()->session->get( 'chosen_shipping_methods' );
        $chosen_shipping = $chosen_methods[0];

        $chosen_method_key = str_replace(':', '_', $chosen_shipping);
        $chosen_method_settings = get_option('woocommerce_' . $chosen_method_key . '_settings');
        if(isset($chosen_method_settings['disable_wcdt']) and !empty($chosen_method_settings['disable_wcdt']) and $chosen_method_settings['disable_wcdt'] === 'yes') return false;



//
//        $chosen_shipping_methods = WC()->session->get( 'chosen_shipping_methods' )[0];
//
//// The array of shipping methods enabled for the current shipping zone:
//        $shipping_methods = WC()->session->get('shipping_for_package_0')['rates'];
//
//// Loop through the array
//        foreach ( $shipping_methods as $method_id => $shipping_rate ){
//            $rate_id        = $shipping_rate->id;
//            $method_id      =  $shipping_rate->method_id;
//            $instance_id    = $shipping_rate->instance_id;
//            $label          =  $shipping_rate->label;
//            $cost           = $shipping_rate->cost;
//            $taxes          = $shipping_rate->taxes;
//
//            // Get the meta data in an unprotected array
//            $meta_data = $shipping_rate->get_meta_data();
//
//            ## ----- BELOW the data you are looking for ----- ##
//
//            $connect_packages = $meta_data['wc_connect_packages'][0];
//
//            $box_id = $connect_packages->box_id; // (string)
//            $length = $connect_packages->length; // (float)
//            $width  = $connect_packages->width;  // (float)
//            $height = $connect_packages->height; // (float)
//            $weight = $connect_packages->weight; // (float)
//            $items  = $connect_packages->items;  // (array of object)
//        }
//
//// OR output the raw data array (test)
//        echo '<pre>'; print_r( $shipping_methods ); echo '</pre>';



//        $rate_table = array();
//        $shipping_methods = WC()->shipping->get_shipping_methods();
//        foreach($shipping_methods as $shipping_method){
//            $settings = $shipping_method->instance_settings;
//
//            foreach($shipping_method->rates as $key=>$val) {
//                if($chosen_shipping === $key) {
//                    if(isset($settings['disable_wcdt']) and !empty($settings['disable_wcdt']) and $settings['disable_wcdt'] === 'yes') return false;
//                }
//            }
//        }

        return $show;
    }

    public function disable_for_virtual_products($show) {
        $disable_for_virtuals = wcdt_get_option('disable_for_digitals');
        if(!isset($disable_for_virtuals) or empty($disable_for_virtuals) or $disable_for_virtuals === 'no') return $show;
        $only_virtual = true;

        foreach( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
            // Check if there are non-virtual products
            if ( ! $cart_item['data']->is_virtual() ) $only_virtual = false;
        }

        if($only_virtual) return false;
        return $show;
    }
}