<?php
namespace WC_Delivery_Time\Includes;
if(!WC_Delivery_Time::is_activated()) return;
if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
    add_action( 'woocommerce_shipping_init', 'WC_Delivery_Time\Includes\WCDT_fast_sending_shipping_method' );
    function WCDT_fast_sending_shipping_method() {
        if ( ! class_exists( 'WCDT_Fast_Sending_Shipping_Method' ) ) {
            class WCDT_Fast_Sending_Shipping_Method extends \WC_Shipping_Method {

                public function __construct( $instance_id = 0 ) {
                    $this->instance_id 	  = absint( $instance_id );
                    $this->id                 = 'fastsending';
                    $this->method_title       = 'ارسال سریع';
                    $this->method_description = 'روش حمل و نقل ارسال سریع افزونه "زمان ارسال کالا"';
                    //add to shipping zones list
                    $this->supports = array(
                        'shipping-zones',
                        //'settings', //use this for separate settings page
                        'instance-settings',
                        'instance-settings-modal',
                    );

                    //make it always enabled
                    $this->title = 'ارسال فوری';
                    $this->enabled = 'yes';

                    $this->init();

                }

                function init() {
                    // Load the settings API
                    $this->init_form_fields();
                    $this->init_settings();

                    // Save settings in admin if you have any defined
                    add_action( 'woocommerce_update_options_shipping_' . $this->id, array( $this, 'process_admin_options' ) );
                }
                //Fields for the settings page
                function init_form_fields() {

                    //fileds for the modal form from the Zones window
                    $this->instance_form_fields = array(

                        'title' => array(
                            'title' => 'عنوان',
                            'type' => 'text',
                            'description' => 'عنوانی که میخواهید در سایت نمایش داده شود.',
                            'default' => 'ارسال فوری'
                        ),

                    );

                    //$this->form_fields - use this with the same array as above for setting fields for separate settings page
                }

                public function calculate_shipping( $package = array()) {
                    $fastsending = wcdt_check_fastsending_exist();
                    if(apply_filters('delivery_time_fastsending_rate', $fastsending)) {
                        $intance_settings = $this->instance_settings;
                        $this->add_rate(array(
                                'id' => $this->id,
                                'label' => $intance_settings['title'],
                                'cost' => 1,
                                'package' => $package,
                                'taxes' => false,
                            )
                        );
                    }
                }
            }
        }

        add_filter( 'woocommerce_shipping_methods', 'WC_Delivery_Time\Includes\add_fast_sending_shipping_method' );
        function add_fast_sending_shipping_method( $methods ) {
            $methods['fastsending'] = 'WC_Delivery_Time\Includes\WCDT_Fast_Sending_Shipping_Method';
            return $methods;
        }
    }
    add_filter( 'woocommerce_package_rates', 'WC_Delivery_Time\Includes\woocommerce_package_rates' );
    function woocommerce_package_rates( $rates ) {
        $fastsending = wcdt_check_fastsending_exist(true);

        if(apply_filters('delivery_time_fastsending_rate', $fastsending['status']))
            $rates['fastsending']->cost = $fastsending['matched_price'];


        return $rates;
    }

    add_action('woocommerce_checkout_update_order_review', 'WC_Delivery_Time\Includes\checkout_update_refresh_shipping_methods', 10, 1);
    function checkout_update_refresh_shipping_methods( $post_data ) {
        $packages = WC()->cart->get_shipping_packages();
        foreach ($packages as $package_key => $package ) {
            WC()->session->set( 'shipping_for_package_' . $package_key, false ); // Or true
        }
    }
}