<?php
namespace WC_Delivery_Time\Includes;

class WC_Delivery_Time_Product_Cat {
    protected static $_instance = null;

    public static function get_instance() {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }

        return self::$_instance;
    }

    public function __construct() {
        add_action('product_cat_add_form_fields', [$this, 'product_cat_add_form_fields']);
        add_action('product_cat_edit_form_fields',[$this, 'product_cat_edit_form_fields'], 10, 2);
        add_action('created_product_cat', [$this, 'created_product_cat'], 10, 2);
        add_action('edited_product_cat', [$this, 'edited_product_cat'], 10, 2);
    }

    public function product_cat_add_form_fields() {
        ?>
        <div class="form-field">
            <label for="wcdt_cat_ready_days">زمان آماده شدن محصول</label>
            <input type="number" id="wcdt_cat_ready_days" name="wcdt_cat_ready_days" />

            <div class="clear"></div>
        </div>
        <div class="form-field">
	        <label for="wcdt_cat_ignore">در نظر نگرفتن دسته در زمان ارسال کالا</label>
            <input type="number" id="wcdt_cat_ignore" name="wcdt_cat_ignore" />

            <div class="clear"></div>
        </div>
        <?php
    }

    public function product_cat_edit_form_fields( $term, $taxonomy ) {
        $default = get_term_meta($term->term_id, '_wcdt_cat_ready_days', true);
        $default = (isset($default) and !empty($default)) ? $default : '';
        $default_ignore = get_term_meta($term->term_id, '_wcdt_cat_ignore', true);
        $default_ignore = (isset($default_ignore) and !empty($default_ignore)) ? $default_ignore : '';
        ?>
        <tr class="form-field">
            <th scope="row" valign="top">
                <label for="wcdt_cat_ready_days">زمان آماده شدن محصول‌ها</label>
            </th>
            <td>
                <input type="text" id="wcdt_cat_ready_days" value="<?php echo $default; ?>" name="wcdt_cat_ready_days" />
                <p class="description">این فیلد اولویت کمتری نسبت به زمان آماده شدن محصول در هر محصول خاص دارد.</p>

            </td>
        </tr>
	    <tr class="form-field">
            <th scope="row" valign="top">
                <label for="wcdt_cat_ignore">در نظر نگرفتن دسته در زمان ارسال کالا</label>
            </th>
            <td>
                <input type="checkbox" id="wcdt_cat_ignore" value="1" name="wcdt_cat_ignore" <?php checked(1, $default_ignore); ?> />
                <p class="description">در صورتی که این گزینه را فعال کنید، محصولات این دسته بندی در زمان ارسال کالا در نظر گرفته نمیشوند.</p>

            </td>
        </tr>
        <div class="clear"></div>

        <?php
    }

    public function created_product_cat( $term_id, $tt_id ) {
        if (isset($_POST['wcdt_cat_ready_days']) && !empty($_POST['wcdt_cat_ready_days'])) {
            update_term_meta($term_id, '_wcdt_cat_ready_days', $_POST['wcdt_cat_ready_days'], true);
        } else {
            delete_term_meta($term_id, '_wcdt_cat_ready_days');
        }

        if (isset($_POST['wcdt_cat_ignore']) && !empty($_POST['wcdt_cat_ignore'])) {
            update_term_meta($term_id, '_wcdt_cat_ignore', $_POST['wcdt_cat_ignore'], true);
        } else {
            delete_term_meta($term_id, '_wcdt_cat_ignore');
        }
    }

    public function edited_product_cat($term_id, $taxonomy) {

        if (isset($_POST['wcdt_cat_ready_days']) && !empty($_POST['wcdt_cat_ready_days'])) {
            update_term_meta($term_id, '_wcdt_cat_ready_days', sanitize_text_field($_POST['wcdt_cat_ready_days']));
        } else {
            delete_term_meta($term_id, '_wcdt_cat_ready_days');
        }

        if (isset($_POST['wcdt_cat_ignore']) && !empty($_POST['wcdt_cat_ignore'])) {
            update_term_meta($term_id, '_wcdt_cat_ignore', sanitize_text_field($_POST['wcdt_cat_ignore']));
        } else {
            delete_term_meta($term_id, '_wcdt_cat_ignore');
        }

    }

}