<?php
namespace WC_Delivery_Time\Includes;

class WC_Delivery_Time_Settings {

    private $settingsSlug = 'wc_delivery_time_settings';
    private $designOptions = [];
    private $tabsSlugs = [];
    private $tabsFields = [];

    /**
     * The single instance of the class.
     *
     * @var WC_Delivery_Time_Settings
     */
    protected static $_instance = null;

    /**
     * Main Class Instance.
     *
     * Ensures only one instance of this class is loaded or can be loaded.
     *
     * @static
     * @return WC_Delivery_Time_Settings - Main instance.
     */

    public static function get_instance() {
        if ( is_null( self::$_instance ) ) {
            self::$_instance = new self();
        }

        return self::$_instance;
    }
    /**
     * WC_Delivery_Time_Settings constructor.
     */
    public function __construct() {
        $this->tabsSlugs            = ['general' => 'تنظیمات عمومی', 'design' => 'تنظیمات ظاهری', 'text' => 'تنظیمات متنی','calendar' => 'تقویم', 'license' => 'لایسنس'];
        $this->tabsFields           = [];


        $this->tabsFields['general']['calendar']                        = [__('Calendar', 'wcdt'), 'wcdt_general'];
        $this->tabsFields['general']['always_show']                     = [__('Always show', 'wcdt'), 'wcdt_general'];
        $this->tabsFields['general']['number_show_days']                = [__('Number of days to show', 'wcdt'), 'wcdt_general'];
        $this->tabsFields['general']['days_start_from']                 = [__('start from', 'wcdt'), 'wcdt_general'];
        $this->tabsFields['general']['week_days_without_delivery']      = [__('Select week days without delivery', 'wcdt'), 'wcdt_general'];
        $this->tabsFields['general']['dates_without_delivery']          = [__('Select dates without delivery', 'wcdt'), 'wcdt_general'];
        $this->tabsFields['general']['show_off_dates']                  = [__('Show off dates', 'wcdt'), 'wcdt_general'];
        $this->tabsFields['general']['deactive_hours_range_default']    = [__('Deactive hours range before ordering', 'wcdt'), 'wcdt_general'];
        $this->tabsFields['general']['show_location']                   = [__('Show location', 'wcdt'), 'wcdt_general'];
        $this->tabsFields['general']['pwsms_compatible']                = [__('Persian Woocommerce Compability', 'wcdt'), 'wcdt_general'];
        $this->tabsFields['general']['disable_for_digitals']            = [__('Disable for digital products', 'wcdt'), 'wcdt_general'];

        $this->tabsFields['general']['days_delivery_hours']             = [__('Select the week days delivery hours', 'wcdt'), 'wcdt_send_hour'];

        $this->tabsFields['general']['fastsending_status']              = [__('Fast Sending', 'wcdt'), 'wcdt_city_conditions'];
        $this->tabsFields['general']['fastsending_default_price']       = ['', 'wcdt_city_conditions'];
        $this->tabsFields['general']['fastsending_enable_all_days']     = ['فعال بودن ارسال سریع در همه بازه های زمانی', 'wcdt_city_conditions'];
        $this->tabsFields['general']['fastsending_hours']               = ['بازه‌های زمانی ارسال فوری', 'wcdt_city_conditions'];
        $this->tabsFields['general']['city_conditions']                 = [__('Select state and city conditions', 'wcdt'), 'wcdt_city_conditions'];
        $this->tabsFields['general']['iranwoo_address']                 = [__('Enable Iran Cities', 'wcdt'), 'wcdt_city_conditions'];

        $this->tabsFields['design']['theme']                            = [__('Theme', 'wcdt'), 'wcdt_design_general'];
        $this->tabsFields['design']['theme_mobile']                     = [__('Mobile Theme', 'wcdt'), 'wcdt_design_general'];
        $this->tabsFields['design']['format']                           = [__('Date Structure', 'wcdt'), 'wcdt_design_general'];

        $this->tabsFields['design']['classic_days_bg']                  = [__('Days background color', 'wcdt'), 'wcdt_design_classic'];
        $this->tabsFields['design']['classic_days_color']               = [__('Days font color', 'wcdt'), 'wcdt_design_classic'];
        $this->tabsFields['design']['classic_days_size']                = [__('Days font size', 'wcdt'), 'wcdt_design_classic'];
        $this->tabsFields['design']['classic_days_weight']              = [__('Days font weight', 'wcdt'), 'wcdt_design_classic'];
        $this->tabsFields['design']['classic_days_date_color']          = [__('Days date font color', 'wcdt'), 'wcdt_design_classic'];
        $this->tabsFields['design']['classic_days_date_size']           = [__('Days date font size', 'wcdt'), 'wcdt_design_classic'];
        $this->tabsFields['design']['classic_days_date_weight']         = [__('Days date font weight', 'wcdt'), 'wcdt_design_classic'];
        $this->tabsFields['design']['classic_hours_size']               = [__('Hour font size', 'wcdt'), 'wcdt_design_classic'];
        $this->tabsFields['design']['classic_hours_weight']             = [__('Hour font weight', 'wcdt'), 'wcdt_design_classic'];
        $this->tabsFields['design']['classic_hours_color']              = [__('Hour font color', 'wcdt'), 'wcdt_design_classic'];
        $this->tabsFields['design']['classic_hours_bg']                 = [__('Hour background color', 'wcdt'), 'wcdt_design_classic'];
        $this->tabsFields['design']['classic_hours_bg_selected']        = [__('Selected hour background color', 'wcdt'), 'wcdt_design_classic'];
        $this->tabsFields['design']['classic_hours_color_selected']     = [__('Selected hour font color', 'wcdt'), 'wcdt_design_classic'];

        $this->tabsFields['design']['digikala_days_bg']                  = [__('Days background color', 'wcdt'), 'wcdt_design_digikala'];
        $this->tabsFields['design']['digikala_days_bg_selected']         = [__('Selected days background color', 'wcdt'), 'wcdt_design_digikala'];
        $this->tabsFields['design']['digikala_days_top_border_selected'] = [__('Selected days top border color', 'wcdt'), 'wcdt_design_digikala'];
        $this->tabsFields['design']['digikala_days_color']               = [__('Days font color', 'wcdt'), 'wcdt_design_digikala'];
        $this->tabsFields['design']['digikala_days_color_selected']      = [__('Selected days font color', 'wcdt'), 'wcdt_design_digikala'];
        $this->tabsFields['design']['digikala_days_size']                = [__('Days font size', 'wcdt'), 'wcdt_design_digikala'];
        $this->tabsFields['design']['digikala_days_size_selected']       = [__('Selected days font size', 'wcdt'), 'wcdt_design_digikala'];
        $this->tabsFields['design']['digikala_days_weight']              = [__('Days font weight', 'wcdt'), 'wcdt_design_digikala'];
        $this->tabsFields['design']['digikala_days_weight_selected']     = [__('Selected days font weight', 'wcdt'), 'wcdt_design_digikala'];
        $this->tabsFields['design']['digikala_days_date_color']          = [__('Days date font color', 'wcdt'), 'wcdt_design_digikala'];
        $this->tabsFields['design']['digikala_days_date_color_selected'] = [__('Selected days date font color', 'wcdt'), 'wcdt_design_digikala'];
        $this->tabsFields['design']['digikala_days_date_size']           = [__('Days date font size', 'wcdt'), 'wcdt_design_digikala'];
        $this->tabsFields['design']['digikala_days_date_size_selected']  = [__('Selected Days date font size', 'wcdt'), 'wcdt_design_digikala'];
        $this->tabsFields['design']['digikala_days_date_weight']         = [__('Days date font weight', 'wcdt'), 'wcdt_design_digikala'];
        $this->tabsFields['design']['digikala_days_date_weight_selected']= [__('Selected Days date font weight', 'wcdt'), 'wcdt_design_digikala'];

        $this->tabsFields['design']['digikala_mobile_days_bg']                  = [__('Days background color', 'wcdt'), 'wcdt_design_digikala_mobile'];
        $this->tabsFields['design']['digikala_mobile_days_bg_selected']         = [__('Selected days background color', 'wcdt'), 'wcdt_design_digikala_mobile'];
        $this->tabsFields['design']['digikala_mobile_days_top_border_selected'] = [__('Selected days top border color', 'wcdt'), 'wcdt_design_digikala_mobile'];
        $this->tabsFields['design']['digikala_mobile_days_color']               = [__('Days font color', 'wcdt'), 'wcdt_design_digikala_mobile'];
        $this->tabsFields['design']['digikala_mobile_days_color_selected']      = [__('Selected days font color', 'wcdt'), 'wcdt_design_digikala_mobile'];
        $this->tabsFields['design']['digikala_mobile_days_size']                = [__('Days font size', 'wcdt'), 'wcdt_design_digikala_mobile'];
        $this->tabsFields['design']['digikala_mobile_days_size_selected']       = [__('Selected days font size', 'wcdt'), 'wcdt_design_digikala_mobile'];
        $this->tabsFields['design']['digikala_mobile_days_weight']              = [__('Days font weight', 'wcdt'), 'wcdt_design_digikala_mobile'];
        $this->tabsFields['design']['digikala_mobile_days_weight_selected']     = [__('Selected days font weight', 'wcdt'), 'wcdt_design_digikala_mobile'];
        $this->tabsFields['design']['digikala_mobile_days_date_color']          = [__('Days date font color', 'wcdt'), 'wcdt_design_digikala_mobile'];
        $this->tabsFields['design']['digikala_mobile_days_date_color_selected'] = [__('Selected days date font color', 'wcdt'), 'wcdt_design_digikala_mobile'];
        $this->tabsFields['design']['digikala_mobile_days_date_size']           = [__('Days date font size', 'wcdt'), 'wcdt_design_digikala_mobile'];
        $this->tabsFields['design']['digikala_mobile_days_date_size_selected']  = [__('Selected Days date font size', 'wcdt'), 'wcdt_design_digikala_mobile'];
        $this->tabsFields['design']['digikala_mobile_days_date_weight']         = [__('Days date font weight', 'wcdt'), 'wcdt_design_digikala_mobile'];
        $this->tabsFields['design']['digikala_mobile_days_date_weight_selected']= [__('Selected Days date font weight', 'wcdt'), 'wcdt_design_digikala_mobile'];

        $this->tabsFields['text']['delivery_time_title']                        = [__('Delivery time title', 'wcdt'), 'wcdt_text_general'];
        $this->tabsFields['text']['not_selected_error']                         = [__('Delivery time Not selected alert', 'wcdt'), 'wcdt_text_general'];


        add_action( 'admin_menu', array( $this, 'settings_admin_menu' ) );
        add_action( 'admin_init', array($this, 'admin_init')) ;
    }

    public function settings_admin_menu() {

        add_submenu_page(
            'woocommerce',
            __('Delivery time', 'wcdt'),
            __('Delivery time', 'wcdt'),
            'manage_options',
            'wc_delivery_time_settings',
            array($this, 'main_menu')
        );

    }

    private function get_tab_url($tab = 'general') {
        return  esc_url( add_query_arg( [ 'tab' => $tab ], admin_url( 'admin.php?page=' . $this->settingsSlug ) ) );
    }

    public function get_current_tab() {
        $active_tab = 'general';
        if( isset($_GET['tab']) and !empty($_GET['tab']) and array_key_exists($_GET['tab'], $this->tabsSlugs) ) $active_tab = $_GET['tab'];
        return $active_tab;
    }

    public function main_menu() {
        ?>
        <div class="wrap wcrp_wrap">
            <h1><?php _e('Woocommerce Delivery Time Settings', 'wcdt'); ?></h1>
            <h2 class="nav-tab-wrapper">
            <?php foreach ($this->tabsSlugs as $tab => $label): ?>
                <a href="<?php echo $this->get_tab_url($tab); ?>" class="nav-tab <?php echo ($this->get_current_tab() == $tab) ? 'nav-tab-active' : ''; ?>"><?php echo $label; ?></a>
            <?php endforeach; ?>
            </h2>
            <?php
            settings_errors();
            $tab = (isset($_GET['tab'] ) and !empty($_GET['tab'] )) ? $_GET['tab'] : '';
            if ( ! isset( $tab ) || isset( $tab ) && 'license' != $tab && 'calendar' != $tab): ?>
            <form method="post" action="options.php">
                <?php
                if('general' === $this->get_current_tab()):
                    settings_fields('wcdt_group');
                    do_settings_sections('wcdt_page');
                elseif('design' === $this->get_current_tab()):
                    settings_fields('wcdt_design_group');
                    do_settings_sections('wcdt_design_page');
                elseif('text' === $this->get_current_tab()):
                    settings_fields('wcdt_text_group');
                    do_settings_sections('wcdt_text_page');
                endif;
                submit_button();
                ?>
            </form>
            <?php else: ?>
                <?php if($tab == 'calendar'): ?>
                    <?php $this->calendar_tab_content(); ?>
                <?php else: ?>
                    <?php $this->activation_tab_content(); ?>
                <?php endif; ?>
            <?php endif; ?>
        </div>
        <?php
    }

    public function activation_tab_content() {
        $option = get_option('wcdt_activation');
        $now = json_decode(get_option($option));
        $starter = (isset($now->starter) && !empty($now->starter)) ? base64_decode($now->starter) : '';
        if( isset($_GET['debugger']) && !empty($_GET['debugger']) && $_GET['debugger'] === 'show' ) {
            $data_show = $option;
        } else {
            $data_show = '';
        }
        ?>
        <style>
            form.register_version_form,
            .current_license {
                width: 30%;
                background: #fff;
                margin: 0 auto;
                padding: 20px 30px;
            }
            form.register_version_form  .license_key {
                padding: 5px 10px;
                width: calc( 100% - 100px );
            }

            form.register_version_form button {
                width: 80px;
                text-align: center;
            }

            form.register_version_form .result,
            .current_license .check_result {
                width: 100%;
                padding: 30px 0 15px;
                text-align: center;
                display: none;
            }
            .current_license .check_result {
                padding: 20px 0;
                float: right;
                width: 100%;
            }
            form.register_version_form .result .spinner,
            .current_license .check_result .spinner {
                width: auto;
                background-position: right center;
                padding-right: 30px;
                margin: 0;
                float: none;
                visibility: visible;
                display: none;
            }
            .current_license.waiting .check_result .spinner,
            form.register_version_form .result.show .spinner {
                display: inline-block;
            }
            .current_license {
                width: 40%;
                text-align: center;
            }
            .current_license > .current_label {
                line-height: 25px;
                height: 25px;
                display: inline-block;
                font-weight: bold;
                margin-left: 10px;
            }
            .current_license > code {
                line-height: 25px;
                height: 25px;
                padding: 0 5px;
                color: #c7254e;
                margin-left: 10px;
                display: inline-block;
                -webkit-transform: translateY(2px);
                -moz-transform: translateY(2px);
                -ms-transform: translateY(2px);
                -o-transform: translateY(2px);
                transform: translateY(2px);
            }
            .current_license .action {
                color: #fff;
                line-height: 25px;
                height: 25px;
                padding: 0 5px;
                display: inline-block;
            }
            .current_license .last_check {
                line-height: 25px;
                height: 25px;
                padding: 0 5px;
                display: inline-block;
            }
            .current_license .action.active {
                background: #4CAF50;
            }
            .current_license .action.inactive {
                background: #c7254e;
            }

            .current_license .keys {
                float: right;
                width: 100%;
                text-align: center;
                padding-top: 20px;
                border-top: 1px solid #ddd;
                margin-top: 20px;
            }
            .current_license .keys .wpmlr_revalidate {
                margin-left: 30px;
            }
            .current_license .register_version_form {
                display: none;
                padding: 0;
                float: right;
                width: 80%;
                margin: 20px 10%;
            }
            .zhk_guard_notice {
                background: #fff;
                border: 1px solid rgba(0,0,0,.1);
                border-right: 4px solid #00a0d2;
                padding: 5px 15px;
                margin: 5px;
            }
            .zhk_guard_danger {
                background: #fff;
                border: 1px solid rgba(0,0,0,.1);
                border-right: 4px solid #DC3232;
                padding: 5px 15px;
                margin: 5px;
            }
            .zhk_guard_success {
                background: #fff;
                border: 1px solid rgba(0,0,0,.1);
                border-right: 4px solid #46b450;
                padding: 5px 15px;
                margin: 5px;
            }
            @media (max-width: 1024px) {
                form.register_version_form,
                .current_license {
                    width: 90%;
                }
            }
        </style>
        <div class="wrap wpmlr_wrap" data-show="<?php echo $data_show ?>">
            <h1><?php _e('Register version', 'wcdt'); ?></h1>
            <?php if( isset($now) && !empty($now) ){ ?>
                <p><?php _e('You already register your license key. to re validate it, you can use this form.', 'wcdt'); ?></p>
                <div class="current_license">
                    <span class="current_label"><?php _e('Your current license:', 'wcdt'); ?></span>
                    <code><?php echo $starter; ?></code>
                    <div class="action <?php echo ($now->action == 1) ? 'active' : 'inactive'; ?>">
                        <?php if( $now->action == 1 ): ?>
                            <span class="dashicons dashicons-yes"></span>
                            <?php echo $now->message; ?>
                        <?php else: ?>
                            <span class="dashicons dashicons-no-alt"></span>
                            <?php echo $now->message; ?>
                        <?php endif; ?>
                    </div>
                    <div class="keys">
                        <a href="#" class="button button-primary wpmlr_revalidate" data-key="<?php echo $starter; ?>"><?php _e('Revalidate', 'wcdt'); ?></a>
                        <a href="#" class="button zhk_guard_new_key"><?php _e('Delete and submit another license', 'wcdt'); ?></a>
                    </div>

                    <form action="#" method="post" class="register_version_form">
                        <input type="text" class="license_key" placeholder="<?php _e('New license key', 'wcdt'); ?>">
                        <button class="button button-primary"><?php _e('Register version', 'wcdt'); ?></button>
                        <div class="result">
                            <div class="spinner"><?php _e('Please wait...', 'wcdt'); ?></div>
                            <div class="result_text"></div>
                        </div>
                    </form>

                    <div class="check_result">
                        <div class="spinner"><?php _e('Please wait...', 'wcdt'); ?></div>
                        <div class="result_text"></div>
                    </div>
                    <div class="clear"></div>
                </div>
                <script>
                jQuery(document).ready(function($) {
                    var ajax_url = "<?php echo admin_url('admin-ajax.php'); ?>";
                    jQuery(document).on('submit', '.register_version_form', function(event) {
                        event.preventDefault();
                        var starter = jQuery(this).find('.license_key').val(),
                            thisEl = jQuery(this);
                        thisEl.addClass('waiting');
                        thisEl.find('.result').slideDown(300).addClass('show');
                        thisEl.find('.button').addClass('disabled');
                        thisEl.find('.result_text').slideUp(300).html('');
                        jQuery.ajax({
                            url: ajax_url,
                            type: 'POST',
                            dataType: 'json',
                            data: {
                                action: 'wcdt_activation',
                                starter: starter
                            },
                        })
                            .done(function(result) {
                                thisEl.find('.result_text').append(result.data).slideDown(150)
                            })
                            .fail(function(result) {
                                thisEl.find('.result_text').append('<div class="zhk_guard_danger"><?php _e('Something goes wrong please try again.', 'wcdt'); ?></div>').slideDown(150)
                            })
                            .always(function(result) {
                                thisEl.removeClass('waiting');
                                thisEl.find('.result').removeClass('show');
                                thisEl.find('.button').removeClass('disabled');
                            });
                    });

                    $(document).on('click', '.wpmlr_revalidate', function(event) {
                        event.preventDefault();
                        var starter = $(this).data('key'),
                            thisEl = $(this).parents('.current_license');
                        thisEl.addClass('waiting');
                        thisEl.find('.check_result').slideDown(300);
                        thisEl.find('.button').addClass('disabled');
                        thisEl.find('.result_text').slideUp(300).html('');
                        thisEl.find('.register_version_form').slideUp(300)
                        $.ajax({
                            url: ajax_url,
                            type: 'POST',
                            dataType: 'json',
                            data: {
                                action: 'wcdt_activation_revalidate',
                                starter: starter
                            },
                        })
                            .done(function(result) {
                                thisEl.find('.check_result .result_text').append(result.data).slideDown(150)
                            })
                            .fail(function(result) {
                                thisEl.find('.check_result .result_text').append('<div class="wpmlr_danger"><?php _e('Something goes wrong please try again.', 'wcdt'); ?></div>').slideDown(150)
                            })
                            .always(function(result) {
                                thisEl.removeClass('waiting');
                                thisEl.find('.button').removeClass('disabled');
                            });
                    });


                    $(document).on('click', '.zhk_guard_new_key', function(event) {
                        event.preventDefault();
                        var thisEl = $(this).parents('.current_license');
                        thisEl.find('.result_text').slideUp(300).html('');
                        thisEl.find('.register_version_form').slideDown(300)
                    });
                });
            </script>
        <?php
        }
    }

    public function calendar_tab_content() {
        require_once 'WC_Delivery_Time_Calendar.php';
        WC_Delivery_Time_Calendar::get_instance();
    }

    public function admin_init() {
        register_setting('wcdt_design_group', 'wcdt_design_options', [$this, 'sanitize_design_options']);
        register_setting('wcdt_text_group', 'wcdt_text_options', [$this, 'sanitize_text_options']);
        register_setting('wcdt_group', 'wcdt_options', [$this, 'sanitize_options']);
        foreach($this->tabsSlugs as $tab => $tabLabel):
            if($tab == $this->get_current_tab()) {

                if($tab === 'design') {
                    add_settings_section('wcdt_design_general', __('General', 'wcdt'),null, 'wcdt_design_page');
                    add_settings_section('wcdt_design_digikala', __('Digikala', 'wcdt'),null, 'wcdt_design_page');
                    add_settings_section('wcdt_design_digikala_mobile', __('Digikala Mobile', 'wcdt'),null, 'wcdt_design_page');
                    add_settings_section('wcdt_design_classic', __('Classic', 'wcdt'),null, 'wcdt_design_page');
                }
                if($tab == 'general') {
                    add_settings_section('wcdt_general', __('General Settings', 'wcdt'),null, 'wcdt_page');
                    add_settings_section('wcdt_send_hour', __('Send hour Settings', 'wcdt'), null, 'wcdt_page');
                    add_settings_section('wcdt_city_conditions','تنظیمات شرایط نمایش و روش ارسال فوری', null,'wcdt_page');
                }
                if($tab == 'text') {
                    add_settings_section('wcdt_text_general', __('General Settings', 'wcdt'),null, 'wcdt_text_page');
                }
                if(!isset($this->tabsFields[$tab]) or empty($this->tabsFields[$tab]) or !is_array($this->tabsFields[$tab])) continue;
                foreach($this->tabsFields[$tab] as $slug => $labelSection) {
                    $page = 'wcdt_'.$tab.'_page';
                    if($tab == 'general') $page = 'wcdt_page';
                    add_settings_field($slug, $labelSection[0], [$this, $slug.'_callback'],$page, $labelSection[1]);
                }
            }
        endforeach;

    }

    public function calendar_callback(){
        $default = self::get_option('calendar');
        ?>
            <select id="calendar" name="wcdt_options[calendar]">
                <option value="jalali" <?php echo ((!isset($default) or empty($default) or $default === 'jalali') ? 'selected' : ''); ?>><?php _e('Jalali', 'wcdt'); ?></option>
                <option value="default" <?php echo ((isset($default) and !empty($default) and $default === 'default') ? 'selected' : ''); ?>><?php _e('Wordpress Default', 'wcdt'); ?></option>
            </select>
        <?php
    }

    public function always_show_callback(){
        $always_show = self::get_option('always_show');
        ?>
            <select id="always_show" name="wcdt_options[always_show]">
                <option value="no" <?php echo ((!isset($always_show) or empty($always_show) or $always_show === 'no') ? 'selected' : ''); ?>><?php _e('no', 'wcdt'); ?></option>
                <option value="yes" <?php echo ((isset($always_show) and !empty($always_show) and $always_show === 'yes') ? 'selected' : ''); ?>><?php _e('yes', 'wcdt'); ?></option>
            </select>
            <span class="description"><?php _e('If you want to show delivery time table without concidering any condition, select yes', 'wcdt'); ?></span>
            <p class="description"><?php _e('This option will be used for stores that removed their city and province from their website checkout', 'wcdt'); ?></p>
        <?php
    }

    public function disable_for_digitals_callback(){
        $default = self::get_option('disable_for_digitals');
        ?>
            <select id="disable_for_digitals" name="wcdt_options[disable_for_digitals]">
                <option value="no" <?php echo ((!isset($default) or empty($default) or $default === 'no') ? 'selected' : ''); ?>><?php _e('no', 'wcdt'); ?></option>
                <option value="yes" <?php echo ((isset($default) and !empty($default) and $default === 'yes') ? 'selected' : ''); ?>><?php _e('yes', 'wcdt'); ?></option>
            </select>
        <?php
    }

    public function theme_callback(){
        $theme = self::get_option('theme', 'design');
        if(!isset($theme) or empty($theme)) $theme = self::get_option('theme');
        ?>
            <select id="theme" name="wcdt_design_options[theme]">
                <option value="classic" <?php echo ((!isset($theme) or empty($theme) or $theme === 'classic') ? 'selected' : ''); ?>><?php _e('classic', 'wcdt'); ?></option>
                <option value="digikala" <?php echo ((isset($theme) and !empty($theme) and $theme === 'digikala') ? 'selected' : ''); ?>><?php _e('digikala', 'wcdt'); ?></option>
                <option value="digikala_mobile" <?php echo ((isset($theme) and !empty($theme) and $theme === 'digikala_mobile') ? 'selected' : ''); ?>>دیجیکالا موبایل</option>
            </select>
        <?php
    }

    public function theme_mobile_callback(){
        $theme = self::get_option('theme_mobile', 'design');
        if(!isset($theme) or empty($theme)) $theme = self::get_option('theme');
        ?>
            <select id="theme_mobile" name="wcdt_design_options[theme_mobile]">
                <option value="default" <?php echo ((!isset($theme) or empty($theme) or $theme === 'default') ? 'selected' : ''); ?>><?php _e('Like the default', 'wcdt'); ?></option>
                <option value="classic" <?php echo ((isset($theme) and !empty($theme) and $theme === 'classic') ? 'selected' : ''); ?>><?php _e('classic', 'wcdt'); ?></option>
                <option value="digikala" <?php echo ((isset($theme) and !empty($theme) and $theme === 'digikala') ? 'selected' : ''); ?>><?php _e('digikala', 'wcdt'); ?></option>
                <option value="digikala_mobile" <?php echo ((isset($theme) and !empty($theme) and $theme === 'digikala_mobile') ? 'selected' : ''); ?>><?php _e('Digikala mobile', 'wcdt'); ?></option>
            </select>
        <?php
    }

    public function format_callback(){
        $default = wcdt_get_option('format', 'design');
        ?>
            <input id="format" name="wcdt_design_options[format]" value="<?php echo !empty($default) ? $default : get_option('date_format'); ?>">
        <?php
    }

    public function digikala_days_bg_callback(){
        $default = wcdt_get_option('digikala_days_bg', 'design');
        ?>
            <input id="digikala_days_bg" name="wcdt_design_options[digikala_days_bg]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_days_bg_selected_callback(){
        $default = wcdt_get_option('digikala_days_bg_selected', 'design');
        ?>
            <input id="digikala_days_bg_selected" name="wcdt_design_options[digikala_days_bg_selected]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_days_top_border_selected_callback(){
        $default = wcdt_get_option('digikala_days_top_border_selected', 'design');
        ?>
            <input id="digikala_days_top_border_selected" name="wcdt_design_options[digikala_days_top_border_selected]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_days_top_border_selected(){
        $default = wcdt_get_option('digikala_days_top_border_selected', 'design');
        ?>
            <input id="digikala_days_top_border_selected" name="wcdt_design_options[digikala_days_top_border_selected]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_days_color_callback(){
        $default = wcdt_get_option('digikala_days_font', 'design');
        ?>
            <input id="digikala_days_font" name="wcdt_design_options[digikala_days_font]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_days_color_selected_callback(){
        $default = wcdt_get_option('digikala_days_color_selected', 'design');
        ?>
            <input id="digikala_days_color_selected" name="wcdt_design_options[digikala_days_color_selected]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_days_size_callback(){
        $default = wcdt_get_option('digikala_days_size', 'design');
        ?>
            <input id="digikala_days_size" name="wcdt_design_options[digikala_days_size]" type="number" value="<?php echo !empty($default) ? $default : 15; ?>">
            <span class="description">پیکسل</span>
        <?php
    }

    public function digikala_days_size_selected_callback(){
        $default = wcdt_get_option('digikala_days_size_selected', 'design');
        ?>
            <input id="digikala_days_size_selected" name="wcdt_design_options[digikala_days_size_selected]" type="number" value="<?php echo !empty($default) ? $default : 15; ?>">
            <span class="description">پیکسل</span>
        <?php
    }

    public function digikala_days_weight_callback(){
        $default = wcdt_get_option('digikala_days_weight', 'design');

        ?>
            <select id="digikala_days_weight" name="wcdt_design_options[digikala_days_weight]">
                <option value="normal" <?php echo ((!isset($default) or empty($default) or $default === 'normal') ? 'selected' : ''); ?>>نرمال</option>
                <option value="bold" <?php echo ((isset($default) and !empty($default) and $default === 'bold') ? 'selected' : ''); ?>>ضخیم</option>
            </select>
        <?php
    }

    public function digikala_days_weight_selected_callback(){
        $default = wcdt_get_option('digikala_days_weight_selected', 'design');

        ?>
            <select id="digikala_days_weight_selected" name="wcdt_design_options[digikala_days_weight_selected]">
                <option value="normal" <?php echo ((!isset($default) or empty($default) or $default === 'normal') ? 'selected' : ''); ?>>نرمال</option>
                <option value="bold" <?php echo ((isset($default) and !empty($default) and $default === 'bold') ? 'selected' : ''); ?>>ضخیم</option>
            </select>
        <?php
    }

    public function digikala_days_date_color_callback(){
        $default = wcdt_get_option('digikala_days_date_color', 'design');
        ?>
            <input id="digikala_days_font" name="wcdt_design_options[digikala_days_date_color]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_days_date_color_selected_callback(){
        $default = wcdt_get_option('digikala_days_date_color_selected', 'design');
        ?>
            <input id="digikala_days_date_color_selected" name="wcdt_design_options[digikala_days_date_color_selected]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_days_date_size_callback(){
        $default = wcdt_get_option('digikala_days_date_size', 'design');
        ?>
            <input id="digikala_days_size" name="wcdt_design_options[digikala_days_date_size]" type="number" value="<?php echo !empty($default) ? $default : 15; ?>">
            <span class="description">پیکسل</span>
        <?php
    }

    public function digikala_days_date_size_selected_callback(){
        $default = wcdt_get_option('digikala_days_date_size_selected', 'design');
        ?>
            <input id="digikala_days_date_size_selected" name="wcdt_design_options[digikala_days_date_size_selected]" type="number" value="<?php echo !empty($default) ? $default : 15; ?>">
            <span class="description">پیکسل</span>
        <?php
    }

    public function digikala_days_date_weight_callback(){
        $default = wcdt_get_option('digikala_days_date_weight', 'design');

        ?>
            <select id="digikala_days_weight" name="wcdt_design_options[digikala_days_date_weight]">
                <option value="normal" <?php echo ((!isset($default) or empty($default) or $default === 'normal') ? 'selected' : ''); ?>>نرمال</option>
                <option value="bold" <?php echo ((isset($default) and !empty($default) and $default === 'bold') ? 'selected' : ''); ?>>ضخیم</option>
            </select>
        <?php
    }

    public function digikala_days_date_weight_selected_callback(){
        $default = wcdt_get_option('digikala_days_date_weight_selected', 'design');

        ?>
            <select id="digikala_days_date_weight_selected" name="wcdt_design_options[digikala_days_date_weight_selected]">
                <option value="normal" <?php echo ((!isset($default) or empty($default) or $default === 'normal') ? 'selected' : ''); ?>>نرمال</option>
                <option value="bold" <?php echo ((isset($default) and !empty($default) and $default === 'bold') ? 'selected' : ''); ?>>ضخیم</option>
            </select>
        <?php
    }

    public function digikala_mobile_days_bg_callback(){
        $default = wcdt_get_option('digikala_mobile_days_bg', 'design');
        ?>
            <input id="digikala_mobile_days_bg" name="wcdt_design_options[digikala_mobile_days_bg]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_mobile_days_bg_selected_callback(){
        $default = wcdt_get_option('digikala_mobile_days_bg_selected', 'design');
        ?>
            <input id="digikala_mobile_days_bg_selected" name="wcdt_design_options[digikala_mobile_days_bg_selected]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_mobile_days_top_border_selected_callback(){
        $default = wcdt_get_option('digikala_mobile_days_top_border_selected', 'design');
        ?>
            <input id="digikala_mobile_days_top_border_selected" name="wcdt_design_options[digikala_mobile_days_top_border_selected]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_mobile_days_top_border_selected(){
        $default = wcdt_get_option('digikala_mobile_days_top_border_selected', 'design');
        ?>
            <input id="digikala_mobile_days_top_border_selected" name="wcdt_design_options[digikala_mobile_days_top_border_selected]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_mobile_days_color_callback(){
        $default = wcdt_get_option('digikala_mobile_days_font', 'design');
        ?>
            <input id="digikala_mobile_days_font" name="wcdt_design_options[digikala_mobile_days_font]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_mobile_days_color_selected_callback(){
        $default = wcdt_get_option('digikala_mobile_days_color_selected', 'design');
        ?>
            <input id="digikala_mobile_days_color_selected" name="wcdt_design_options[digikala_mobile_days_color_selected]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_mobile_days_size_callback(){
        $default = wcdt_get_option('digikala_mobile_days_size', 'design');
        ?>
            <input id="digikala_mobile_days_size" name="wcdt_design_options[digikala_mobile_days_size]" type="number" value="<?php echo !empty($default) ? $default : 15; ?>">
            <span class="description">پیکسل</span>
        <?php
    }

    public function digikala_mobile_days_size_selected_callback(){
        $default = wcdt_get_option('digikala_mobile_days_size_selected', 'design');
        ?>
            <input id="digikala_mobile_days_size_selected" name="wcdt_design_options[digikala_mobile_days_size_selected]" type="number" value="<?php echo !empty($default) ? $default : 15; ?>">
            <span class="description">پیکسل</span>
        <?php
    }

    public function digikala_mobile_days_weight_callback(){
        $default = wcdt_get_option('digikala_mobile_days_weight', 'design');

        ?>
            <select id="digikala_mobile_days_weight" name="wcdt_design_options[digikala_mobile_days_weight]">
                <option value="normal" <?php echo ((!isset($default) or empty($default) or $default === 'normal') ? 'selected' : ''); ?>>نرمال</option>
                <option value="bold" <?php echo ((isset($default) and !empty($default) and $default === 'bold') ? 'selected' : ''); ?>>ضخیم</option>
            </select>
        <?php
    }

    public function digikala_mobile_days_weight_selected_callback(){
        $default = wcdt_get_option('digikala_mobile_days_weight_selected', 'design');

        ?>
            <select id="digikala_mobile_days_weight_selected" name="wcdt_design_options[digikala_mobile_days_weight_selected]">
                <option value="normal" <?php echo ((!isset($default) or empty($default) or $default === 'normal') ? 'selected' : ''); ?>>نرمال</option>
                <option value="bold" <?php echo ((isset($default) and !empty($default) and $default === 'bold') ? 'selected' : ''); ?>>ضخیم</option>
            </select>
        <?php
    }

    public function digikala_mobile_days_date_color_callback(){
        $default = wcdt_get_option('digikala_mobile_days_date_font', 'design');
        ?>
            <input id="digikala_mobile_days_font" name="wcdt_design_options[digikala_mobile_days_date_font]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_mobile_days_date_color_selected_callback(){
        $default = wcdt_get_option('digikala_mobile_days_date_color_selected', 'design');
        ?>
            <input id="digikala_mobile_days_date_color_selected" name="wcdt_design_options[digikala_mobile_days_date_color_selected]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function digikala_mobile_days_date_size_callback(){
        $default = wcdt_get_option('digikala_mobile_days_date_size', 'design');
        ?>
            <input id="digikala_mobile_days_size" name="wcdt_design_options[digikala_mobile_days_date_size]" type="number" value="<?php echo !empty($default) ? $default : 15; ?>">
            <span class="description">پیکسل</span>
        <?php
    }

    public function digikala_mobile_days_date_size_selected_callback(){
        $default = wcdt_get_option('digikala_mobile_days_date_size_selected', 'design');
        ?>
            <input id="digikala_mobile_days_date_size_selected" name="wcdt_design_options[digikala_mobile_days_date_size_selected]" type="number" value="<?php echo !empty($default) ? $default : 15; ?>">
            <span class="description">پیکسل</span>
        <?php
    }

    public function digikala_mobile_days_date_weight_callback(){
        $default = wcdt_get_option('digikala_mobile_days_date_weight', 'design');

        ?>
            <select id="digikala_mobile_days_weight" name="wcdt_design_options[digikala_mobile_days_date_weight]">
                <option value="normal" <?php echo ((!isset($default) or empty($default) or $default === 'normal') ? 'selected' : ''); ?>>نرمال</option>
                <option value="bold" <?php echo ((isset($default) and !empty($default) and $default === 'bold') ? 'selected' : ''); ?>>ضخیم</option>
            </select>
        <?php
    }

    public function digikala_mobile_days_date_weight_selected_callback(){
        $default = wcdt_get_option('digikala_mobile_days_date_weight_selected', 'design');

        ?>
            <select id="digikala_mobile_days_date_weight_selected" name="wcdt_design_options[digikala_mobile_days_date_weight_selected]">
                <option value="normal" <?php echo ((!isset($default) or empty($default) or $default === 'normal') ? 'selected' : ''); ?>>نرمال</option>
                <option value="bold" <?php echo ((isset($default) and !empty($default) and $default === 'bold') ? 'selected' : ''); ?>>ضخیم</option>
            </select>
        <?php
    }

    public function delivery_time_title_callback(){
        $default = wcdt_get_option('delivery_time_title', 'text');
        ?>
            <input id="delivery_time_title" class="regular-text" name="wcdt_text_options[delivery_time_title]" type="text" value="<?php echo !empty($default) ? $default : ''; ?>">
            <span class="description"><?php _e('Will be replace with default text'); ?></span>
        <?php
    }

    public function not_selected_error_callback(){
        $default = wcdt_get_option('not_selected_error', 'text');
        ?>
            <input id="not_selected_error" class="regular-text" name="wcdt_text_options[not_selected_error]" type="text" value="<?php echo !empty($default) ? $default : ''; ?>">
            <span class="description"><?php _e('Will be replace with default text'); ?></span>
        <?php
    }

    public function classic_days_bg_callback(){
        $default = wcdt_get_option('classic_days_bg', 'design');
        ?>
            <input id="classic_days_bg" name="wcdt_design_options[classic_days_bg]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function classic_days_color_callback(){
        $default = wcdt_get_option('classic_days_color', 'design');
        ?>
            <input id="classic_days_color" name="wcdt_design_options[classic_days_color]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function classic_days_size_callback(){
        $default = wcdt_get_option('classic_days_size', 'design');
        ?>
            <input id="classic_days_size" name="wcdt_design_options[classic_days_size]" type="number" value="<?php echo !empty($default) ? $default : 15; ?>">
            <span class="description">پیکسل</span>
        <?php
    }

    public function classic_days_weight_callback(){
        $default = wcdt_get_option('classic_days_weight', 'design');

        ?>
            <select id="classic_days_weight" name="wcdt_design_options[classic_days_weight]">
                <option value="normal" <?php echo ((!isset($default) or empty($default) or $default === 'normal') ? 'selected' : ''); ?>>نرمال</option>
                <option value="bold" <?php echo ((isset($default) and !empty($default) and $default === 'bold') ? 'selected' : ''); ?>>ضخیم</option>
            </select>
        <?php
    }

    public function classic_hours_size_callback(){
        $default = wcdt_get_option('classic_hours_size', 'design');
        ?>
            <input id="classic_hours_size" name="wcdt_design_options[classic_hours_size]" type="number" value="<?php echo !empty($default) ? $default : 15; ?>">
            <span class="description">پیکسل</span>
        <?php
    }

    public function classic_hours_weight_callback(){
        $default = wcdt_get_option('classic_hours_weight', 'design');

        ?>
            <select id="classic_hours_weight" name="wcdt_design_options[classic_hours_weight]">
                <option value="normal" <?php echo ((!isset($default) or empty($default) or $default === 'normal') ? 'selected' : ''); ?>>نرمال</option>
                <option value="bold" <?php echo ((isset($default) and !empty($default) and $default === 'bold') ? 'selected' : ''); ?>>ضخیم</option>
            </select>
        <?php
    }

    public function classic_days_date_color_callback(){
        $default = wcdt_get_option('classic_days_date_color', 'design');
        ?>
            <input id="classic_days_date_color" name="wcdt_design_options[classic_days_date_color]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function classic_hours_color_callback(){
        $default = wcdt_get_option('classic_hours_color', 'design');
        ?>
            <input id="classic_hours_color" name="wcdt_design_options[classic_hours_color]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function classic_hours_bg_callback(){
        $default = wcdt_get_option('classic_hours_bg', 'design');
        ?>
            <input id="classic_hours_bg" name="wcdt_design_options[classic_hours_bg]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function classic_hours_bg_selected_callback(){
        $default = wcdt_get_option('classic_hours_bg_selected', 'design');
        ?>
            <input id="classic_hours_bg_selected" name="wcdt_design_options[classic_hours_bg_selected]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function classic_hours_color_selected_callback(){
        $default = wcdt_get_option('classic_hours_color_selected', 'design');
        ?>
            <input id="classic_hours_color_selected" name="wcdt_design_options[classic_hours_color_selected]" class="color-field" value="<?php echo !empty($default) ? $default : ''; ?>">
        <?php
    }

    public function classic_days_date_size_callback(){
        $default = wcdt_get_option('classic_days_date_size', 'design');
        ?>
            <input id="classic_days_size" name="wcdt_design_options[classic_days_date_size]" type="number" value="<?php echo !empty($default) ? $default : 15; ?>">
            <span class="description">پیکسل</span>
        <?php
    }

    public function classic_days_date_weight_callback(){
        $default = wcdt_get_option('classic_days_date_weight', 'design');

        ?>
            <select id="classic_days_weight" name="wcdt_design_options[classic_days_date_weight]">
                <option value="normal" <?php echo ((!isset($default) or empty($default) or $default === 'normal') ? 'selected' : ''); ?>>نرمال</option>
                <option value="bold" <?php echo ((isset($default) and !empty($default) and $default === 'bold') ? 'selected' : ''); ?>>ضخیم</option>
            </select>
        <?php
    }

    public function number_show_days_callback(){
        printf(
            '<input class="regular-text" type="text" name="wcdt_options[number_show_days]" id="number_show_days" value="%s"><p class="description">%s</p>',
            self::get_option('number_show_days'),
            __( 'Enter numbr of the days that you want to show in delivery time', 'wcdt' )
        );
    }

    public function days_start_from_callback(){
        printf(
            '<input class="regular-text" type="text" name="wcdt_options[days_start_from]" id="days_start_from" value="%s"><span class="description">%s</span><p class="description">%s</p>',
            self::get_option('days_start_from') === 0 ? '0' : self::get_option('days_start_from'),
            __( 'Start the delivery time days within the above day', 'wcdt' ),
            __( 'For example, If you insert 2 for the above option, and today is saturday, the delivery time starts with monday!', 'wcdt' )
        );
    }

    public function dates_without_delivery_callback(){
        printf(
            '<ul class="show_dates_without_delivery"></ul><textarea name="wcdt_options[dates_without_delivery]" id="dates_without_delivery">%s</textarea><br/><div class="dates_without_delivery_result"></div>
<div class="days-without-delivery-btn"><input style="width: 0; border: none; opacity: 0;    position: absolute;left: 0;" class="regular-text dates_without_delivery" type="text"><a href="#" class="delivery-time-date-selection">%s</a></div>
<span class="description">%s</span><p class="description">%s</p>',
            self::get_option('dates_without_delivery'),
            __( 'select date', 'wcdt' ),
            __( 'This option would not show the days that you have not delivery option', 'wcdt' ),
            __( 'Enter the dates that you have not any delivery', 'wcdt' )
        );
    }

    public function show_off_dates_callback(){
        $show_off_dates = self::get_option('show_off_dates');
        ?>
            <select id="always_show" name="wcdt_options[show_off_dates]">
                <option value="no" <?php echo ((!isset($show_off_dates) or empty($show_off_dates) or $show_off_dates === 'no') ? 'selected' : ''); ?>><?php _e('Do not show', 'wcdt'); ?></option>
                <option value="yes" <?php echo ((isset($show_off_dates) and !empty($show_off_dates) and $show_off_dates === 'yes') ? 'selected' : ''); ?>><?php _e('Show', 'wcdt'); ?></option>
            </select>
            <span class="description"><?php _e('Select "do not show" if you want to not show off dates in delivery table', 'wcdt'); ?></span>
        <?php
    }

    public function deactive_hours_range_default_callback() {
        $hour = self::get_option('deactive_hours_range_default');
        if(!isset($hour) or empty($hour)) {
            $hour = 0;
        }
        printf(
            '<input class="regular-text" type="number" name="wcdt_options[deactive_hours_range_default]" id="deactive_hours_range_default" value="%s"><span class="description">%s</span><p class="description">%s</p><p class="description">%s</p><p class="description">%s</p><p class="description">%s</p>',
            $hour,
            __( 'Enter in hour, for example 8', 'wcdt' ),
            __( 'Deactive hours range before ordering', 'wcdt' ),
            __( 'This Option can be overrided by the value of each range', 'wcdt' ),
            __( 'For example if user is purchasing at 12 o\'clock and wants to select the 13-15 range, if you fill 3 this option, the user cant select 13-15 range the order should be submitted before 10 o\'clock', 'wcdt' ),
            '<b style="color: #000">عدد منفی به معنی در نظر گرفتن از آخر بازه زمانی است.</b>'
        );
    }

    public function order_status_after_payment_callback(){
        $selectedStatus = self::get_option('order_status_after_payment');
        $statuses = wc_get_order_statuses();
        ?>
            <select id="order_status_after_payment" name="wcdt_options[order_status_after_payment]">
            <?php
            foreach ( $statuses as $status => $status_name ) {
		        echo '<option value="' . esc_attr( $status ).'"' . ($selectedStatus === esc_attr( $status ) ? 'selected' : '') . '>' . esc_html( $status_name ) . '</option>';
            }
            ?>
            </select>
            <span class="description"><?php _e('Select default order status after payment.', 'wcdt'); ?></span>
            <p class="description"><?php _e('This option will be handle order volume in a delivery range', 'wcdt'); ?></p>
            <p class="description"><?php _e('We are not using this option to override other order status plugins or woocommerce settings', 'wcdt'); ?></p>
        <?php
    }

    public function show_location_callback() {
        $showLocation = self::get_option('show_location');

        $options = array(
            'woocommerce_review_order_before_payment' => __('Before payment', 'wcdt'),
            'woocommerce_review_order_after_payment' => __('After payment', 'wcdt'),
            'woocommerce_before_checkout_form' => __('Before checkout form', 'wcdt'),
            'woocommerce_after_checkout_form' => __('After checkout form', 'wcdt'),
            'woocommerce_checkout_before_order_review' => __('Before order review', 'wcdt'),
            'woocommerce_checkout_after_order_review' => __('After order review', 'wcdt'),
            'woocommerce_checkout_before_customer_details' => __('Before customer details', 'wcdt'),
        'woocommerce_checkout_after_customer_details' => __('After customer details', 'wcdt'),
        );
        $options = apply_filters('delivery_time_field_location', $options);
        ?>

        <select id="order_status_after_payment" name="wcdt_options[show_location]">
            <?php
            foreach ( $options as $key => $name ) {
		        echo '<option value="' . esc_attr( $key ).'"' . ($key === esc_attr( $showLocation ) ? 'selected' : '') . '>' . esc_html( $name ) . '</option>';
            }
            ?>
        </select>
        <span class="description"><?php _e('Delivery time show location in checkout page', 'wcdt'); ?></span>
        <p class="description"><?php _e('If you are using some plugins to change checkout form, this behavior maybe change!', 'wcdt'); ?></p>

        <?php
    }

    public function pwsms_compatible_callback() {
         $default = self::get_option('pwsms_compatible');
        ?>
            <select id="fastsending_status" name="wcdt_options[pwsms_compatible]">
                <option value="enable" <?php echo ((isset($default) and !empty($default) and $default === 'enable') ? 'selected' : ''); ?>>فعال</option>
                <option value="disable" <?php echo ((!isset($default) or empty($default) or $default === 'disable') ? 'selected' : ''); ?>>غیرفعال</option>
            </select>
            <p class="description">هماهنگی با افزونه persian woocommerce sms</p>
            <p class="description">این قابلیت فقط در صورت فعال بودن افزونه پیامک فارسی ووکامرس عمل خواهد کرد.</p>
        <?php
    }

    public function fastsending_hours_callback() {
        $fastsending_hours = self::get_option('fastsending_hours');
        ?>
            <div class="fastsending-hours">
            <div class="fastsending-hours-container">
            <div class="fastsending-day heading">
                <div class="f-name">روز هفته</div>
                <div class="f-start">ساعت آغاز</div>
                <div class="f-end">ساعت پایان</div>
                <div class="f-end">تمام روز</div>
            </div>
            <?php
            $week_days = [
                'Saturday'  => __('Saturday', 'wcdt'),
                'Sunday'    => __('Sunday', 'wcdt'),
                'Monday'    => __('Monday', 'wcdt'),
                'Tuesday'   => __('Tuesday', 'wcdt'),
                'Wednesday' => __('Wednesday', 'wcdt'),
                'Thursday'  => __('Thursday', 'wcdt'),
                'Friday'    => __('Friday', 'wcdt'),
                ];
            foreach($week_days as $key => $value):
            $default_start  = (isset($fastsending_hours[$key]['start']) and !empty($fastsending_hours[$key]['start'])) ? $fastsending_hours[$key]['start'] : 0;
            $default_end    = (isset($fastsending_hours[$key]['end']) and !empty($fastsending_hours[$key]['end'])) ? $fastsending_hours[$key]['end'] : 0;
            $defaut_all    = (isset($fastsending_hours[$key]['all']) and !empty($fastsending_hours[$key]['all'])) ? $fastsending_hours[$key]['all'] : 0;
            ?>
            <div class="fastsending-day">
                <div class="f-name"><?php echo $value; ?></div>
                <div class="f-start"><input type="number" name="wcdt_options[fastsending_hours][<?php echo $key; ?>][start]" value="<?php echo $default_start; ?>"></div>
                <div class="f-end"><input type="number" name="wcdt_options[fastsending_hours][<?php echo $key; ?>][end]" value="<?php echo $default_end; ?>"></div>
                <div class="f-all"><input type="checkbox" name="wcdt_options[fastsending_hours][<?php echo $key; ?>][all]" value="1" <?php echo $defaut_all ? 'checked' : ''; ?>></div>
            </div>
            <?php endforeach; ?>
            </div>
            </div>
            <p class="description">بازه های زمانی سفارش‌گیری ارسال فوری را مشخحص میکند.</p>
            <p class="description">در صورتی که روز سفارش گیری در روزهای تعطیل انتخاب شده در تنظیمات باشد، ارسال فوری نمایش داده نخواهد شد.</p>
        <?php
    }

    public function week_days_without_delivery_callback(){
        $days = self::get_option('week_days_without_delivery');
        if(!isset($days) or empty($days)) {
            $days = array();
        }
        ?>
            <select id="week_days_without_delivery" name="wcdt_options[week_days_without_delivery][]" multiple>
                <option value="saturday" <?php echo in_array('saturday', $days) ? 'selected' : '' ?>><?php _e('saturday', 'wcdt'); ?></option>
                <option value="sunday" <?php echo in_array('sunday', $days) ? 'selected' : '' ?>><?php _e('sunday', 'wcdt'); ?></option>
                <option value="monday" <?php echo in_array('monday', $days) ? 'selected' : '' ?>><?php _e('monday', 'wcdt'); ?></option>
                <option value="tuesday" <?php echo in_array('tuesday', $days) ? 'selected' : '' ?>><?php _e('tuesday', 'wcdt'); ?></option>
                <option value="wednesday" <?php echo in_array('wednesday', $days) ? 'selected' : '' ?>><?php _e('wednesday', 'wcdt'); ?></option>
                <option value="thursday" <?php echo in_array('thursday', $days) ? 'selected' : '' ?>><?php _e('thursday', 'wcdt'); ?></option>
                <option value="friday" <?php echo in_array('friday', $days) ? 'selected' : '' ?>><?php _e('friday', 'wcdt'); ?></option>
            </select>
            <span class="description"><?php _e('select week days that you have not any delivery', 'wcdt'); ?></span>
            <p class="description"><?php _e('This option have higher priority with delivery date', 'wcdt'); ?></p>
        <?php
    }

    public function get_days_hours($day) {
        $delivery_hours = self::get_option('days_delivery_hours');
        if(isset($delivery_hours[$day]) and !empty($delivery_hours[$day])) {
            $hours = $delivery_hours[$day];
        } else {
            $hours = array();
        }
        foreach($hours as $hour) {
            ?>
            <div class="hour-range">
                <span class="remove">x</span>
                <input type="text" class="days_delivery_hours" name="wcdt_options[days_delivery_hours][<?php echo $day; ?>][]" value="<?php echo $hour; ?>">
            </div>
            <?php
        }
    }

    public function days_delivery_hours_callback() {
        ?>
            <div id="new-hours-range-popup">
                <div class="section half" >
                    <label for="range-from"><?php _e('range from', 'wcdt'); ?></label>
                    <input id="range-from" class="new-hours-range-field" type="text" value="0" placeholder="<?php _e('enter start range', 'wcdt'); ?>">
                </div>
                <div class="section half" >
                    <label for="range-to"><?php _e('range to', 'wcdt'); ?></label>
                    <input id="range-to" class="new-hours-range-field" type="text" value="0" placeholder="<?php _e('enter end range', 'wcdt'); ?>">
                </div>
                <div class="section half" >
                    <label for="range-volume"><?php _e('range volume', 'wcdt'); ?></label>
                    <input id="range-volume" class="new-hours-range-field" type="text" value="0" placeholder="<?php _e('enter range volume', 'wcdt'); ?>">
                    <p>
                        <span><?php _e('delivery limit for this time range', 'wcdt'); ?></span>
                        <span><?php _e('if you leave this section with 0, there is no limit for this delivery time range', 'wcdt'); ?></span>
                    </p>
                </div>
                <div class="section half" >
                    <label for="range-deactive-hour"><?php _e('hours before order to active', 'wcdt'); ?></label>
                    <input id="range-deactive-hour" class="new-hours-range-field" type="number" placeholder="<?php _e('enter hours before order to active this range', 'wcdt'); ?>">
                    <p>
                        <span><?php _e('Spicify hours that this range will be active to order', 'wcdt'); ?></span>
                        <span><?php _e('If you leave this option -1, the default value will be set for this range', 'wcdt'); ?></span>
                    </p>
                </div>
                <div class="section full" >
                    <a href="#" class="new-hours-add-button"><?php _e('new range', 'wcdt'); ?></a>
                </div>
            </div>
            <div class="delivery-date-settings select-hours">
                <div class="row week-day" data-day="saturday">
                    <div class="week-day-name">
                        <span><?php _e('saturday', 'wcdt'); ?></span>
                        <a href="#" class="new-hours-range"><?php _e('add a range', 'wcdt'); ?></a>

                    </div>
                    <div class="week-day-hours">
                        <?php echo $this->get_days_hours('saturday'); ?>
                    </div>
                </div>
            </div>
            <div class="delivery-date-settings select-hours">
                <div class="row week-day" data-day="sunday">
                    <div class="week-day-name">
                        <span><?php _e('sunday', 'wcdt'); ?></span>
                        <a href="#" class="new-hours-range"><?php _e('add a range', 'wcdt'); ?></a>

                    </div>
                    <div class="week-day-hours">
                        <?php echo $this->get_days_hours('sunday'); ?>
                    </div>
                </div>
            </div>
            <div class="delivery-date-settings select-hours">
                <div class="row week-day" data-day="monday">
                    <div class="week-day-name">
                        <span><?php _e('monday', 'wcdt'); ?></span>
                        <a href="#" class="new-hours-range"><?php _e('add a range', 'wcdt'); ?></a>

                    </div>
                    <div class="week-day-hours">
                         <?php echo $this->get_days_hours('monday'); ?>
                    </div>
                </div>
            </div>
            <div class="delivery-date-settings select-hours">
                <div class="row week-day" data-day="tuesday">
                    <div class="week-day-name">
                        <span><?php _e('tuesday', 'wcdt'); ?></span>
                        <a href="#" class="new-hours-range"><?php _e('add a range', 'wcdt'); ?></a>

                    </div>
                    <div class="week-day-hours">
                         <?php echo $this->get_days_hours('tuesday'); ?>
                    </div>
                </div>
            </div>
            <div class="delivery-date-settings select-hours">
                <div class="row week-day" data-day="wednesday">
                    <div class="week-day-name">
                        <span><?php _e('wednesday', 'wcdt'); ?></span>
                        <a href="#" class="new-hours-range"><?php _e('add a range', 'wcdt'); ?></a>

                    </div>
                    <div class="week-day-hours">
                         <?php echo $this->get_days_hours('wednesday'); ?>
                    </div>
                </div>
            </div>
            <div class="delivery-date-settings select-hours">
                <div class="row week-day" data-day="thursday">
                    <div class="week-day-name">
                        <span><?php _e('thursday', 'wcdt'); ?></span>
                        <a href="#" class="new-hours-range"><?php _e('add a range', 'wcdt'); ?></a>

                    </div>
                    <div class="week-day-hours">
                         <?php echo $this->get_days_hours('thursday'); ?>
                    </div>
                </div>
            </div>
            <div class="delivery-date-settings select-hours">
                <div class="row week-day" data-day="friday">
                    <div class="week-day-name">
                        <span><?php _e('friday', 'wcdt'); ?></span>
                        <a href="#" class="new-hours-range"><?php _e('add a range', 'wcdt'); ?></a>

                    </div>
                    <div class="week-day-hours">
                         <?php echo $this->get_days_hours('friday'); ?>
                    </div>
                </div>
            </div>
        <?php
    }

    public function fastsending_status_callback() {
        $fastsending_status = self::get_option('fastsending_status');
        ?>
            <select id="fastsending_status" name="wcdt_options[fastsending_status]">
                <option value="enable" <?php echo ((isset($fastsending_status) and !empty($fastsending_status) and $fastsending_status === 'enable') ? 'selected' : ''); ?>>فعال</option>
                <option value="disable" <?php echo ((!isset($fastsending_status) or empty($fastsending_status) or $fastsending_status === 'disable') ? 'selected' : ''); ?>>غیرفعال</option>
            </select>
            <p class="description">فعال بودن روش ارسال فوری</p>
        <?php
    }

    public function fastsending_default_price_callback() {
        $default = self::get_option('fastsending_default_price');
        if(!isset($default) or empty($default)) $default = 0;
        printf(
            '<input class="regular-text" type="number" name="wcdt_options[fastsending_default_price]" id="fastsending_default_price" value="%s"><p class="description">%s</p>',
            $default,
            'این هزینه در صورت فعال بودن گزینه نمایش همیشگی در نظر گرفته میشود.'
            );
    }

    public function fastsending_enable_all_days_callback() {
        $fastsending_enable_all_days = self::get_option('fastsending_enable_all_days');
        ?>
            <select id="fastsending_status" name="wcdt_options[fastsending_enable_all_days]">
                <option value="enable" <?php echo ((isset($fastsending_enable_all_days) and !empty($fastsending_enable_all_days) and $fastsending_enable_all_days === 'enable') ? 'selected' : ''); ?>>فعال</option>
                <option value="disable" <?php echo ((!isset($fastsending_enable_all_days) or empty($fastsending_enable_all_days) or $fastsending_enable_all_days === 'disable') ? 'selected' : ''); ?>>غیرفعال</option>
            </select>
            <p class="description">در صورت فعال بودن این گزینه، بازه های ارسال فوری در نظر گرفته نمیشوند.</p>
        <?php
    }

    public function iranwoo_address_callback() {
        $iranwoo_address = self::get_option('iranwoo_address');
        ?>
            <select id="iranwoo_address" name="wcdt_options[iranwoo_address]">
                <option value="enable" <?php echo ((isset($iranwoo_address) and !empty($iranwoo_address) and $iranwoo_address === 'enable') ? 'selected' : ''); ?>>فعال</option>
                <option value="disable" <?php echo ((!isset($iranwoo_address) or empty($iranwoo_address) or $iranwoo_address === 'disable') ? 'selected' : ''); ?>>غیرفعال</option>
            </select>
            <p class="description">فعال بودن لیست شهر های ایران در صفحه تسویه حساب</p>
        <?php
    }

    public function city_conditions_callback() {
        ?>

        <div class="list_cities_conditions">
        <?php
            $conditionsList = self::get_option('city_conditions');
            if(isset($conditionsList) and !empty($conditionsList)) {
                foreach($conditionsList as $key => $condition) {
                ?>
                <a href="#" class="city-remove" data-attr="<?php echo $key; ?>">X</a>
                <div class="city-condition-section" data-attr="<?php echo $key; ?>">
                    <label><?php _e('province', 'wcdt'); ?></label>
                    <select name="wcdt_options[city_conditions][<?php echo $key; ?>][province]" class="province deactive" data-province="<?php echo (isset($condition['province']) and !empty($condition['province'])) ? $condition['province'] : ''; ?>"></select>

                    <label style="display: <?php echo (isset($condition['province_only']) and !empty($condition['province_only']) and $condition['province_only'] == 'yes') ? 'none' : 'inline-block'; ?>"><?php _e('city', 'wcdt'); ?></label>
                    <select name="wcdt_options[city_conditions][<?php echo $key; ?>][city]" data-city="<?php echo (isset($condition['city']) and !empty($condition['city'])) ? $condition['city'] : '' ?>" class="city" style="display: <?php echo (isset($condition['province_only']) and !empty($condition['province_only']) and $condition['province_only'] == 'yes') ? 'none' : 'inline-block'; ?>"></select>

                    <div class="item">
                        <input type="checkbox" id="province_only_<?php echo $key; ?>" name="wcdt_options[city_conditions][<?php echo $key; ?>][province_only]" <?php echo (isset($condition['province_only']) and !empty($condition['province_only']) and $condition['province_only'] == 'yes') ? 'checked' : ''; ?> value="yes">
                        <label for="province_only_<?php echo $key; ?>">در نظر گرفتن کل استان</label>
                    </div>

                    <div class="item">
                        <input type="checkbox" class="fast_sending_status" id="fast_sending_<?php echo $key; ?>" name="wcdt_options[city_conditions][<?php echo $key; ?>][fast_sending]"  <?php echo (isset($condition['fast_sending']) and !empty($condition['fast_sending']) and $condition['fast_sending'] == 'yes') ? 'checked' : ''; ?> value="yes">
                        <label for="fast_sending_<?php echo $key; ?>">ارسال فوری</label>
                    </div>
                    <div class="item" style="display: <?php echo (isset($condition['fast_sending']) and !empty($condition['fast_sending']) and $condition['fast_sending'] == 'yes') ? 'block' : 'none'; ?>">
                        <label for="fast_sending_price_<?php echo $key; ?>">هزینه ارسال فوری: </label>
                        <input type="number" id="fast_sending_<?php echo $key; ?>" style="width: 100px" name="wcdt_options[city_conditions][<?php echo $key; ?>][fast_sending_price]" value="<?php echo (isset($condition['fast_sending_price']) and !empty($condition['fast_sending_price'])) ? $condition['fast_sending_price'] : ''; ?>">
                    </div>
                    <div class="item" style="display: <?php echo (isset($condition['fast_sending']) and !empty($condition['fast_sending']) and $condition['fast_sending'] == 'yes') ? 'block' : 'none'; ?>">
                        <input type="checkbox" id="fast_sending_disable_dt_<?php echo $key; ?>" name="wcdt_options[city_conditions][<?php echo $key; ?>][fast_sending_disable_dt]"  <?php echo (isset($condition['fast_sending_disable_dt']) and !empty($condition['fast_sending_disable_dt']) and $condition['fast_sending_disable_dt'] == 'yes') ? 'checked' : ''; ?> value="yes">
                        <label for="fast_sending_disable_dt_<?php echo $key; ?>">نمایش ندادن انتخاب ساعت ارسال بعد از انتخاب ارسال فوری</label>
                    </div>
                </div>
                <?php
                }
            }
        ?>

        </div>
        <a href="#" id="new_city_condition"><?php _e('add new condition', 'wcdt'); ?></a>
        <?php
    }

    public static function pws_province_list() {

    }

    public static function get_option($option_name = false, $tab = 'general') {
        return wcdt_get_option($option_name, $tab);
    }

    public function sanitize_options($settings) {
        if($settings['fastsending_status'] == 'enable') {
            $instance_id = self::get_option('fastsending_method_instance_id');
            if(!isset($instance_id) or empty($instance_id)) {
                $zone        = new \WC_Shipping_Zone( 0 );
                $instance_id = $zone->add_shipping_method( wc_clean( wp_unslash( 'fastsending' ) ) );
		    }
            $settings['fastsending_method_instance_id'] = $instance_id;
		} else {
            $instance_id = self::get_option('fastsending_method_instance_id');
            $zone        = new \WC_Shipping_Zone( 0 );
            $zone->delete_shipping_method($instance_id);
            unset($settings['fastsending_method_instance_id']);
		}
        foreach($settings['city_conditions'] as $key => $condition) {
            if(empty($condition['province'])) {
                unset($settings['city_conditions'][$key]);
                continue;
            }
            if($condition['province_only']) unset($settings['city_conditions'][$key]['city']);
        }
        return $settings;
    }

}